==> grpc_0.11.1.orig.tar.gz: grpc-0.11.1/src/csharp/Grpc.Core/ServerPort.cs <==
#region Copyright notice and license

// Copyright 2015, Google Inc.
// All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are
// met:
//
//     * Redistributions of source code must retain the above copyright
// notice, this list of conditions and the following disclaimer.
//     * Redistributions in binary form must reproduce the above
// copyright notice, this list of conditions and the following disclaimer
// in the documentation and/or other materials provided with the
// distribution.
//     * Neither the name of Google Inc. nor the names of its
// contributors may be used to endorse or promote products derived from
// this software without specific prior written permission.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
// "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
// LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
// A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
// OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
// SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
// LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
// DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
// THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
// (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
// OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

#endregion

using System;

using Grpc.Core.Utils;

namespace Grpc.Core
{
    /// <summary>
    /// A port exposed by a server.
    /// </summary>
    public class ServerPort
    {
        /// <summary>
        /// Pass this value as port to have the server choose an unused listening port for you.
        /// Ports added to a server will contain the bound port in their <see cref="BoundPort"/> property.
        /// </summary>
        public const int PickUnused = 0;

        readonly string host;
        readonly int port;
        readonly ServerCredentials credentials;
        readonly int boundPort;

        /// <summary>
        /// Creates a new port on which server should listen.
        /// </summary>
        /// <returns>The port on which server will be listening.</returns>
        /// <param name="host">the host</param>
        /// <param name="port">the port. If zero, an unused port is chosen automatically.</param>
        /// <param name="credentials">credentials to use to secure this port.</param>
        public ServerPort(string host, int port, ServerCredentials credentials)
        {
            this.host = Preconditions.CheckNotNull(host, "host");
            this.port = port;
            this.credentials = Preconditions.CheckNotNull(credentials, "credentials");
        }

        /// <summary>
        /// Creates a port from an existing <c>ServerPort</c> instance and boundPort value.
        /// </summary>
        internal ServerPort(ServerPort serverPort, int boundPort)
        {
            this.host = serverPort.host;
            this.port = serverPort.port;
            this.credentials = serverPort.credentials;
            this.boundPort = boundPort;
        }

        /// <value>The host.</value>
        public string Host
        {
            get
            {
                return host;
            }
        }

        /// <value>The port.</value>
        public int Port
        {
            get
            {
                return port;
            }
        }

        /// <value>The server credentials.</value>
        public ServerCredentials Credentials
        {
            get
            {
                return credentials;
            }
        }

        /// <value>
        /// The port actually bound by the server. This is useful if you let server
        /// pick port automatically. <see cref="PickUnused"/>
        /// </value>
        public int BoundPort
        {
            get
            {
                return boundPort;
            }
        }
    }
}

==> grpc_1.3.2.orig.tar.gz: grpc-1.3.2/src/csharp/Grpc.Core/ServerPort.cs <==
#region Copyright notice and license

// Copyright 2015, Google Inc.
// All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are
// met:
//
//     * Redistributions of source code must retain the above copyright
// notice, this list of conditions and the following disclaimer.
//     * Redistributions in binary form must reproduce the above
// copyright notice, this list of conditions and the following disclaimer
// in the documentation and/or other materials provided with the
// distribution.
//     * Neither the name of Google Inc. nor the names of its
// contributors may be used to endorse or promote products derived from
// this software without specific prior written permission.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
// "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
// LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
// A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
// OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
// SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
// LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
// DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
// THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
// (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
// OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

#endregion

using System;

using Grpc.Core.Utils;

namespace Grpc.Core
{
    /// <summary>
    /// A port exposed by a server.
    /// </summary>
    public class ServerPort
    {
        /// <summary>
        /// Pass this value as port to have the server choose an unused listening port for you.
        /// Ports added to a server will contain the bound port in their <see cref="BoundPort"/> property.
        /// </summary>
        public const int PickUnused = 0;

        readonly string host;
        readonly int port;
        readonly ServerCredentials credentials;
        readonly int boundPort;

        /// <summary>
        /// Creates a new port on which server should listen.
        /// </summary>
        /// <returns>The port on which server will be listening.</returns>
        /// <param name="host">the host</param>
        /// <param name="port">the port. If zero, an unused port is chosen automatically.</param>
        /// <param name="credentials">credentials to use to secure this port.</param>
        public ServerPort(string host, int port, ServerCredentials credentials)
        {
            this.host = GrpcPreconditions.CheckNotNull(host, "host");
            this.port = port;
            this.credentials = GrpcPreconditions.CheckNotNull(credentials, "credentials");
        }

        /// <summary>
        /// Creates a port from an existing <c>ServerPort</c> instance and boundPort value.
        /// </summary>
        internal ServerPort(ServerPort serverPort, int boundPort)
        {
            this.host = serverPort.host;
            this.port = serverPort.port;
            this.credentials = serverPort.credentials;
            this.boundPort = boundPort;
        }

        /// <value>The host.</value>
        public string Host
        {
            get
            {
                return host;
            }
        }

        /// <value>The port.</value>
        public int Port
        {
            get
            {
                return port;
            }
        }

        /// <value>The server credentials.</value>
        public ServerCredentials Credentials
        {
            get
            {
                return credentials;
            }
        }

        /// <value>
        /// The port actually bound by the server. This is useful if you let server
        /// pick port automatically. <see cref="PickUnused"/>
        /// </value>
        public int BoundPort
        {
            get
            {
                return boundPort;
            }
        }
    }
}
